==> haskell-zlib-0.6.2.3-71-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-zlib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 zlib
version:              0.6.2.3
visibility:           public
id:                   zlib-0.6.2.3-CHiFTEFy3O189HdNi87aSY
key:                  zlib-0.6.2.3-CHiFTEFy3O189HdNi87aSY
license:              BSD-3-Clause
copyright:            (c) 2006-2016 Duncan Coutts
maintainer:
    Duncan Coutts <duncan@community.haskell.org>, Andrew Lelechenko <andrew.lelechenko@gmail.com>, Emily Pillmore <emilypi@cohomolo.gy>, Herbert Valerio Riedel <hvr@gnu.org>

author:               Duncan Coutts <duncan@community.haskell.org>
synopsis:             Compression and decompression in the gzip and zlib formats
description:
    This package provides a pure interface for compressing and
    decompressing streams of data represented as lazy
    '\''ByteString'\''s. It uses the
    <https://en.wikipedia.org/wiki/Zlib zlib C library>
    so it has high performance. It supports the \"zlib\",
    \"gzip\" and \"raw\" compression formats.

    It provides a convenient high level API suitable for most
    tasks and for the few cases where more control is needed it
    provides access to the full zlib feature set.

category:             Codec
abi:                  7baa27c9c034f44589c2b6a1fbddc2d4
exposed:              True
exposed-modules:
    Codec.Compression.GZip Codec.Compression.Zlib
    Codec.Compression.Zlib.Internal Codec.Compression.Zlib.Raw

hidden-modules:
    Codec.Compression.Zlib.Stream
    Codec.Compression.Zlib.ByteStringCompat

import-dirs:          /usr/lib/ghc-9.0.2/site-local/zlib-0.6.2.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/zlib-0.6.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-zlib
hs-libraries:         HSzlib-0.6.2.3-CHiFTEFy3O189HdNi87aSY
extra-libraries:      z
includes:             zlib.h
depends:              base-4.15.1.0 bytestring-0.10.12.1
haddock-interfaces:   /usr/share/doc/haskell-zlib/html/zlib.haddock
haddock-html:         /usr/share/doc/haskell-zlib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-zlib-0.6.2.3-72-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-zlib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 zlib
version:              0.6.2.3
visibility:           public
id:                   zlib-0.6.2.3-2r5IqjO5wuX8tSDW54PthL
key:                  zlib-0.6.2.3-2r5IqjO5wuX8tSDW54PthL
license:              BSD-3-Clause
copyright:            (c) 2006-2016 Duncan Coutts
maintainer:
    Duncan Coutts <duncan@community.haskell.org>, Andrew Lelechenko <andrew.lelechenko@gmail.com>, Emily Pillmore <emilypi@cohomolo.gy>, Herbert Valerio Riedel <hvr@gnu.org>

author:               Duncan Coutts <duncan@community.haskell.org>
synopsis:             Compression and decompression in the gzip and zlib formats
description:
    This package provides a pure interface for compressing and
    decompressing streams of data represented as lazy
    '\''ByteString'\''s. It uses the
    <https://en.wikipedia.org/wiki/Zlib zlib C library>
    so it has high performance. It supports the \"zlib\",
    \"gzip\" and \"raw\" compression formats.

    It provides a convenient high level API suitable for most
    tasks and for the few cases where more control is needed it
    provides access to the full zlib feature set.

category:             Codec
abi:                  92b28bab4eaaa400f7a5717951b10482
exposed:              True
exposed-modules:
    Codec.Compression.GZip Codec.Compression.Zlib
    Codec.Compression.Zlib.Internal Codec.Compression.Zlib.Raw

hidden-modules:
    Codec.Compression.Zlib.Stream
    Codec.Compression.Zlib.ByteStringCompat

import-dirs:          /usr/lib/ghc-9.0.2/site-local/zlib-0.6.2.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/zlib-0.6.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-zlib
hs-libraries:         HSzlib-0.6.2.3-2r5IqjO5wuX8tSDW54PthL
extra-libraries:      z
includes:             zlib.h
depends:              base-4.15.1.0 bytestring-0.10.12.1
haddock-interfaces:   /usr/share/doc/haskell-zlib/html/zlib.haddock
haddock-html:         /usr/share/doc/haskell-zlib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
